@@ -735,7 +735,7 @@ class DB_MySQL:
             installed TINYINT DEFAULT 0,\
             version TINYINT\
             )")
-            db[1].execute("INSERT IGNORE into in_status VALUE (0,0,0,0,0)")
+            db[1].execute("INSERT IGNORE into in_status VALUE (0,0,0,0,0,0)")
         except:
             ""
         self.close_db(db)
