@@ -30,7 +30,7 @@ use Sort::Naturally;
 ################ バージョン定義 ################
 
 
-my $rectool_version = 96;
+my $rectool_version = 98;
 
 
 ################ 初期化ここから ################
@@ -638,6 +638,7 @@ EOM
 	}
 	else {
 		$type = 'reserve_flexible';
+		$counter = -1;
 		$datetime_now = DateTime->now( time_zone => $tz )->set_second( 0 )->add( minutes => 1)->strftime( '%Y-%m-%d %H:%M:%S' );
 		$button_bgn = qq{<button type="button" onClick="document.reserve.begin.value='$datetime_now'">現在</button>\n<br>\n};
 		$button_end = 
@@ -817,8 +818,8 @@ if ( $mode eq 'change' ) {
 		my $pass    = $q->param( 'pass' )    || '';
 
 		$dbh->do( 
-			"INSERT INTO in_settings ( auto_jbk, auto_bayes, auto_del_tmp, auto_opt ) 
-			VALUES ( '$jbk', '$bayes', '$del_tmp', '$opt' )"
+			"UPDATE in_settings SET auto_jbk = '$jbk', auto_bayes = '$bayes', 
+			auto_del_tmp = '$del_tmp', auto_opt = '$opt'"
 		);
 
 		goto end;
@@ -1820,6 +1821,7 @@ sub draw_form_opt {
 	$HTML .= qq {<option value="W" $selected{W}>W 854x480</option>\n};
 	$HTML .= qq {<option value="H" $selected{H}>H 1280x720</option>\n};
 	$HTML .= qq {<option value="F" $selected{F}>F 1920x1080</option>\n};
+	$HTML .= qq {<option value="I" $selected{I}>I インタレ保持</option>\n};
 	$HTML .= qq {</select>\n};
 
 	$HTML .= qq {<select name="opt">\n};
